@@ -24,13 +24,13 @@ void print_warnings(Key * err)
 /** After writing the key this function rereads the key and print it*/
 void check_key()
 {
-	Key * error_key = keyNew(KEY_END);
+	Key * error_key = keyNew(0);
 	KDB * kdb_handle = kdbOpen(error_key);
-	Key * top = keyNew(KEY_END);
+	Key * top = keyNew(0);
 	keySetName(top, "user/sw/MyApp"); // == 14
 	KeySet * ks = ksNew(0, KS_END);
 	kdbGet(kdb_handle, ks, top);
-	Key * key = keyNew(KEY_END);
+	Key * key = keyNew(0);
 	keySetName(key, "user/sw/MyApp/Tests/TestKey1"); // == 14
 	Key * result = ksLookup(ks, key, KDB_O_NONE);
 	const char * key_name = keyName(result);
@@ -47,15 +47,15 @@ void check_key()
 // typical usage of Elektra
 int main()
 {
-	Key * error_key = keyNew(KEY_END);
+	Key * error_key = keyNew(0);
 	KDB * kdb_handle = kdbOpen(error_key);
-	Key * top = keyNew(KEY_END);
+	Key * top = keyNew(0);
 	keySetName(top, "user/sw/MyApp");
 
 	KeySet * ks = ksNew(0, KS_END);
 	kdbGet(kdb_handle, ks, top);
 
-	Key * key = keyNew(KEY_END);
+	Key * key = keyNew(0);
 	keySetName(key, "user/sw/MyApp/Tests/TestKey1"); // == 31
 	keySetString(key, "NULLTestValue"); // == 14
 	keySetMeta(key, "comment", "NULLTestComment"); // == 16
