@@ -1,7 +1,7 @@
 /**
  * @file
  *
- * This examples show how elektras KDBException can be changed in a way
+ * This examples show how Elektra's KDBException can be changed in a way
  * so that it has user defined output.
  *
  * It works -- because of binary compatibility -- if only the receiver
@@ -24,20 +24,21 @@ inline std::ostream & printError(std::ostream & os, kdb::Key const & error)
 {
 	os << "User defined IO (errors)" << std::endl;
 
-	if (!error.getMeta<const kdb::Key>("error"))
-	{
-		// no error available
-		return os;
-	}
+	try {
+		if (!error.getMeta<const kdb::Key>("error"))
+		{
+			// no error available
+			return os;
+		}
 
-	try{
-		error.getMeta<std::string>("error");
 		os << "Error number " << error.getMeta<std::string>("error/number") << " occurred!" << std::endl;
 		os << "Description: " << error.getMeta<std::string>("error/description") << std::endl;
 		os << "Ingroup: " << error.getMeta<std::string>("error/ingroup") << std::endl;
 		os << "Module: " << error.getMeta<std::string>("error/module") << std::endl;
 		os << "At: " << error.getMeta<std::string>("error/file") << ":" << error.getMeta<std::string>("error/line") << std::endl;
 		os << "Reason: " << error.getMeta<std::string>("error/reason") << std::endl;
+		os << "Mountpoint: " << error.getMeta<std::string>("error/mountpoint") << std::endl;
+		os << "Configfile: " << error.getMeta<std::string>("error/configfile") << std::endl;
 	} catch (kdb::KeyTypeConversion const& e)
 	{
 		os << "Error meta data is not set correctly by a plugin" << std::endl;
@@ -50,13 +51,13 @@ inline std::ostream & printWarnings(std::ostream & os, kdb::Key const & error)
 {
 	os << "User defined IO (warnings)" << std::endl;
 
-	if (!error.getMeta<const kdb::Key>("warnings"))
-	{
-		// no warnings were issued
-		return os;
-	}
+	try {
+		if (!error.getMeta<const kdb::Key>("warnings"))
+		{
+			// no warnings were issued
+			return os;
+		}
 
-	try{
 		int nr = error.getMeta<int>("warnings");
 		if (!nr)
 		{
@@ -79,6 +80,8 @@ inline std::ostream & printWarnings(std::ostream & os, kdb::Key const & error)
 			os << "\tAt: " << error.getMeta<std::string>(name.str() + "/file") << ":"
 				  << error.getMeta<std::string>(name.str() + "/line") << std::endl;
 			os << "\tReason: " << error.getMeta<std::string>(name.str() + "/reason") << std::endl;
+			os << "\tMountpoint: " << error.getMeta<std::string>(name.str() + "/mountpoint") << std::endl;
+			os << "\tConfigfile: " << error.getMeta<std::string>(name.str() + "/configfile") << std::endl;
 		}
 
 	} catch (kdb::KeyTypeConversion const& e)
