@@ -132,12 +132,11 @@ public:
 	const_reverse_iterator rbegin() const;
 	reverse_iterator rend();
 	const_reverse_iterator rend() const;
-#if __cplusplus > 199711L
+
 	const_iterator cbegin() const noexcept;
 	const_iterator cend() const noexcept;
 	const_reverse_iterator crbegin() const noexcept;
 	const_reverse_iterator crend() const noexcept;
-#endif
 #endif //ELEKTRA_WITHOUT_ITERATOR
 
 
@@ -153,6 +152,7 @@ public:
 
 	inline bool isNull() const;
 	inline operator bool() const;
+	inline bool needSync() const;
 
 
 	// value operations
@@ -438,7 +438,6 @@ inline Key::const_reverse_iterator Key::rend() const
 	return Key::const_reverse_iterator(*this, false);
 }
 
-#if __cplusplus > 199711L
 inline Key::const_iterator Key::cbegin() const noexcept
 {
 	return Key::const_iterator(*this, true);
@@ -458,7 +457,6 @@ inline Key::const_reverse_iterator Key::crend() const noexcept
 {
 	return Key::const_reverse_iterator(*this, false);
 }
-#endif
 #endif //ELEKTRA_WITHOUT_ITERATOR
 
 
@@ -967,6 +965,14 @@ inline bool Key::isNull() const
 	return key == 0;
 }
 
+/**
+ * @copydoc keyNeedSync
+ */
+inline bool Key::needSync() const
+{
+	return ckdb::keyNeedSync(key);
+}
+
 /**
  * Get a key value.
  *
@@ -1007,7 +1013,6 @@ inline T Key::get() const
 }
 
 /*
-#if __cplusplus > 199711L
 // TODO: are locale dependent
 //   + throw wrong exception (easy to fix though)
 template <>
@@ -1057,7 +1062,6 @@ inline long double Key::get<long double>() const
 {
 	return stold(getString());
 }
-#endif
 */
 
 
@@ -1089,7 +1093,6 @@ inline void Key::set(T x)
 }
 
 /*
-#if __cplusplus > 199711L
 // TODO: are locale dependent
 template <>
 inline void Key::set(int val)
@@ -1144,7 +1147,6 @@ inline void Key::set(long double val)
 {
 	setString(std::to_string(val));
 }
-#endif
 */
 
 
@@ -1202,9 +1204,7 @@ inline ssize_t Key::getStringSize() const
 inline Key::func_t Key::getFunc() const
 {
 	union {Key::func_t f; void* v;} conversation;
-#if __cplusplus > 199711L
 	static_assert(sizeof(conversation) == sizeof(func_t), "union does not have size of function pointer");
-#endif
 
 	if (ckdb::keyGetBinary(getKey(),
 			&conversation.v,
@@ -1218,12 +1218,11 @@ inline Key::func_t Key::getFunc() const
 inline void Key::setCallback(callback_t fct)
 {
 	union {callback_t f; void* v;} conversation;
-#if __cplusplus > 199711L
 	static_assert(sizeof(conversation) == sizeof(callback_t), "union does not have size of function pointer");
-#endif
 
 	conversation.f = fct;
 	ckdb::keySetBinary(getKey(), &conversation.v, sizeof(conversation));
+	ckdb::keySetMeta(getKey(), "callback", "");
 }
 
 
@@ -1644,7 +1643,8 @@ inline int Key::del ()
 
 } // end of namespace kdb
 
-#if __cplusplus > 199711L
+
+#ifdef ELEKTRA_WITH_HASH
 namespace std
 {
 	/**
@@ -1659,7 +1659,7 @@ namespace std
 		}
 	};
 } // end of namespace std
-#endif
+#endif // ELEKTRA_WITH_HASH
 
 #endif
 
