@@ -2,6 +2,8 @@
 #include <glib-object.h>
 #include <tests.h>
 
+#define TEST_NS "user/tests/glib"
+
 static void test_open_close()
 {
 	GElektraKdb *kdb;
@@ -33,6 +35,7 @@ static void test_get_set()
 	GElektraKeySet *ks;
 	GElektraKey *key, *base, *error;
 
+	/*** set ***/
 	/* open kdb */
 	error = gelektra_key_new(NULL);
 	kdb = gelektra_kdb_open(error);
@@ -40,16 +43,16 @@ static void test_get_set()
 	ks = gelektra_keyset_new(100, GELEKTRA_KEYSET_END);
 
 	/* fetch keys below user/MyApp */
-	base = gelektra_key_new("user/MyApp", GELEKTRA_KEY_END);
+	base = gelektra_key_new(TEST_NS, GELEKTRA_KEY_END);
 	gelektra_kdb_get(kdb, ks, base);
 
 	/* search for user/MyApp/mykey */
-	key = gelektra_keyset_lookup_byname(ks, "user/MyApp/mykey",
+	key = gelektra_keyset_lookup_byname(ks, TEST_NS "/mykey",
 		GELEKTRA_KDB_O_NONE);
 	if (!key)
 	{
 		/* key doesn't exist, create a new one and append to keyset */
-		key = gelektra_key_new("user/MyApp/mykey", GELEKTRA_KEY_END);
+		key = gelektra_key_new(TEST_NS "/mykey", GELEKTRA_KEY_END);
 		/* make sure key still exists after append */
 		g_object_ref(key);
 		gelektra_keyset_append(ks, key);
@@ -66,13 +69,14 @@ static void test_get_set()
 	gelektra_kdb_close(kdb, NULL);
 	g_object_unref(kdb);
 
+	/*** get ***/
 	/* open kdb again */
 	kdb = gelektra_kdb_open(error);
 
 	/* check if the value is stored */
 	gelektra_keyset_clear(ks);
 	gelektra_kdb_get(kdb, ks, base);
-	key = gelektra_keyset_lookup_byname(ks, "user/MyApp/mykey",
+	key = gelektra_keyset_lookup_byname(ks, TEST_NS "/mykey",
 		GELEKTRA_KDB_O_NONE);
 	succeed_if(key != NULL, "key hasn't been stored");
 	g_object_unref(key);
@@ -80,6 +84,14 @@ static void test_get_set()
 	/* close kdb. if we don't care about the error value unref is enough */
 	g_object_unref(kdb);
 
+	/*** cleanup ***/
+	kdb = gelektra_kdb_open(error);
+	gelektra_keyset_clear(ks);
+	gelektra_kdb_get(kdb, ks, base);
+	gelektra_keyset_cut(ks, base);
+	gelektra_kdb_set(kdb, ks, base);
+	g_object_unref(kdb);
+
 	g_object_unref(base);
 	g_object_unref(ks);
 	g_object_unref(error);
@@ -92,13 +104,8 @@ int main(int argc, char **argv)
 
 	init(argc, argv);
 
-#if 0
-#error disabled until elektra libraries can be loaded by \
-	the build system (and static build is gone)
-
 	test_open_close();
 	test_get_set();
-#endif
 
 	printf("\n%s RESULTS: %d test(s) done. %d error(s).\n", argv[0],
 		nbTest, nbError);
