@@ -63,7 +63,7 @@
 #define KDBOS_H
 
 #ifdef __cplusplus
-#define KS_END ((ckdb::Key*)0)
+#define KS_END (static_cast<ckdb::Key*>(0))
 #else
 #define KS_END ((Key*)0)
 #endif
@@ -74,6 +74,12 @@
 #define ELEKTRA_SENTINEL  __attribute__ ((sentinel))
 #endif
 
+#ifdef __GNUC__
+#define ELEKTRA_NOINLINE __attribute__((noinline))
+#else
+#define ELEKTRA_NOINLINE
+#endif
+
 #ifndef WIN32
 
 /***************************************************
