@@ -27,10 +27,6 @@ extern "C" {
 #endif
 
 
-// is the unescaped name useful for applications?
-const void *keyUnescapedName(const Key *key);
-ssize_t keyGetUnescapedNameSize(const Key *key);
-
 // can be made simply without elektra's internals, so better keep it as
 // extension.
 ssize_t keySetStringF(Key *key, const char *format, ...);
@@ -64,7 +60,8 @@ enum elektraLookupOptions
 	KDB_O_CREATE=1<<16,        ///< Create the key if it was not found
 	KDB_O_NOCASCADING=1<<17,   ///< Disable cascading search for keys starting with /
 	KDB_O_NOSPEC=1<<18,        ///< Do not use specification for cascading keys (internal)
-	KDB_O_NODEFAULT=1<<19      ///< Do not honor the default spec (internal)
+	KDB_O_NODEFAULT=1<<19,     ///< Do not honor the default spec (internal)
+	KDB_O_CALLBACK=1<<20       ///< For spec/ lookups that traverse deeper into hierarchy (callback in ksLookup())
 };
 
 /**
