@@ -34,29 +34,6 @@
 #include "kdbconfig.h"
 
 #ifdef __cplusplus
-#if __cplusplus <= 199711L
-// for C++97 or older
-
-#include <stdint.h>
-#include <inttypes.h>
-
-namespace kdb
-{
-	typedef int16_t short_t; // default: 0
-	typedef int32_t long_t; // default: 0
-	typedef int64_t long_long_t; // default: 0
-	typedef uint16_t unsigned_short_t; // default: 0
-	typedef uint32_t unsigned_long_t; // default: 0
-	typedef uint64_t unsigned_long_long_t; // default: 0
-	typedef float float_t; // default: 0.0
-	typedef double double_t; // default: 0.0
-	typedef long double long_double_t; // default: 0.0
-	typedef unsigned char char_t; // default: 0
-	typedef bool boolean_t; // default: false
-	typedef uint8_t octet_t; // default: 0
-	// using wchar_t; // default: 0 wchar_t not supported!
-}
-#else
 // for C++11 or later
 
 namespace kdb
@@ -75,7 +52,6 @@ namespace kdb
 	using boolean_t = bool; // default: false
 	using octet_t = uint8_t; // default: 0
 }
-#endif
 #endif // for c++
 
 
