@@ -36,11 +36,7 @@ protected:
 	virtual ConflictOperation getTheirConflictOperation(const Key& conflictKey);
 };
 
-#if __cplusplus > 199711L
 typedef std::unique_ptr<MergeConflictStrategy> MergeConflictStrategyPtr;
-#else
-typedef std::auto_ptr<MergeConflictStrategy> MergeConflictStrategyPtr;
-#endif
 
 }
 }
