@@ -22,6 +22,15 @@ TEST(RebasePath, RebasesCorrectlyWithValidArguments)
 	EXPECT_EQ ("user/test/confignew/subdir/k1", rebasePath (target, oldParent, newParent));
 }
 
+TEST(RebasePath, RebasesCorrectlyWithCascadingParent)
+{
+	Key target = Key ("user/test/configold/subdir/k1", KEY_END);
+	Key oldParent = Key ("/test/configold", KEY_END);
+	Key newParent = Key ("user/test/confignew", KEY_END);
+
+	EXPECT_EQ ("user/test/confignew/subdir/k1", rebasePath (target, oldParent, newParent));
+}
+
 TEST(RebasePath, WorksForKeyOnSameLevel)
 {
 	Key target = Key ("user/test/configold", KEY_END);
@@ -54,6 +63,19 @@ TEST(RebaseKey, RebasesCorrectlyWithValidArguments)
 	EXPECT_EQ (expected.getString(), result.getString());
 }
 
+TEST(RebaseKey, RebasesCorrectlyWithCascadingParent)
+{
+	Key target = Key ("user/test/configold/subdir/k1", KEY_VALUE, "testvalue", KEY_END);
+	Key oldParent = Key ("/test/configold", KEY_END);
+	Key newParent = Key ("user/test/confignew", KEY_END);
+	Key expected = Key ("user/test/confignew/subdir/k1", KEY_VALUE, "testvalue", KEY_END);
+
+	Key result = rebaseKey (target, oldParent, newParent);
+
+	EXPECT_EQ (expected.getName(), result.getName());
+	EXPECT_EQ (expected.getString(), result.getString());
+}
+
 TEST(RebaseKey, ThrowsExceptionOnInvalidRebase)
 {
 	Key target = Key ("user/test/k1", KEY_END);
