@@ -9,6 +9,7 @@
 
 #include <iostream>
 #include <gtest/gtest.h>
+#include <kdbprivate.h>
 #include "mergetestutils.cpp"
 
 using namespace kdb;
@@ -33,6 +34,25 @@ TEST_F(ThreeWayMergeTest, EqualKeySetsMerge)
 	compareAllKeys (merged);
 }
 
+TEST_F(ThreeWayMergeTest, EqualKeySetsWontCauseSync)
+{
+	unsyncKeys(ours);
+	unsyncKeys(theirs);
+	unsyncKeys(base);
+
+	MergeResult result = merger.mergeKeySet (base, ours, theirs, ourParent);
+	EXPECT_FALSE(result.hasConflicts()) << "Invalid conflict detected";
+
+	KeySet merged = result.getMergedKeys();
+
+	Key current;
+	merged.rewind();
+	while ((current = merged.next ()))
+	{
+		EXPECT_FALSE(current.needSync());
+	}
+}
+
 TEST_F(ThreeWayMergeTest, CascadingParentsCauseNoCascadingKeys)
 {
 	Key root("/", KEY_END);
