@@ -196,20 +196,7 @@ int elektraCcodeGet(Plugin *handle, KeySet *returned, Key *parentKey)
 				KEY_FUNC, elektraCcodeGet, KEY_END),
 			keyNew ("system/elektra/modules/ccode/exports/set",
 				KEY_FUNC, elektraCcodeSet, KEY_END),
-			keyNew ("system/elektra/modules/ccode/infos",
-				KEY_VALUE, "All information you want to know", KEY_END),
-			keyNew ("system/elektra/modules/ccode/infos/author",
-				KEY_VALUE, "Markus Raab <elektra@markus-raab.org>", KEY_END),
-			keyNew ("system/elektra/modules/ccode/infos/licence",
-				KEY_VALUE, "BSD", KEY_END),
-			keyNew ("system/elektra/modules/ccode/infos/description",
-				KEY_VALUE, "Decoding/Encoding engine which escapes unwanted characters.", KEY_END),
-			keyNew ("system/elektra/modules/ccode/infos/provides",
-				KEY_VALUE, "code", KEY_END),
-			keyNew ("system/elektra/modules/ccode/infos/placements",
-				KEY_VALUE, "postgetstorage presetstorage", KEY_END),
-			keyNew ("system/elektra/modules/ccode/infos/needs",
-				KEY_VALUE, "", KEY_END),
+#include "readme_ccode.c"
 			keyNew ("system/elektra/modules/ccode/infos/version",
 				KEY_VALUE, PLUGINVERSION, KEY_END),
 			KS_END);
