@@ -28,25 +28,29 @@
 #include <tests_plugin.h>
 
 
-void test_readfstab()
+void test_readfstab(const char * file)
 {
-	Key * parentKey = keyNew ("user/tests/fstab", KEY_VALUE, srcdir_file("fstab/fstab"), KEY_END);
+	Key * parentKey = keyNew ("user/tests/fstab", KEY_VALUE, srcdir_file(file), KEY_END);
 	KeySet *conf = 0;
 	PLUGIN_OPEN("fstab");
 
 	KeySet *ks=ksNew(0, KS_END);
 
-	printf ("Using file: %s\n", srcdir_file("fstab/fstab"));
+	printf ("Reading fstab using file: %s\n", file);
 
 	succeed_if (plugin->kdbGet(plugin, ks, parentKey) >= 1, "call to kdbGet was not successful");
 
 	// output_keyset(ks);
 
-	Key *key = ksLookupByName(ks, "user/tests/fstab/mediaext4/device",0);
+	Key *key = ksLookupByName(ks, "user/tests/fstab/\\//device",0);
 	exit_if_fail (key, "rootfs device not found");
+	succeed_if (strcmp( "/dev/sda1", keyValue(key)) == 0, "device not correct");
+
+	key = ksLookupByName(ks, "user/tests/fstab/\\/media\\/ext4/device",0);
+	exit_if_fail (key, "media device not found");
 	succeed_if (strcmp( "/dev/sdg1", keyValue(key)) == 0, "device not correct");
 
-	exit_if_fail (key = ksLookupByName(ks, "user/tests/fstab/mediaext4/dumpfreq",0), "rootfs device not found");
+	exit_if_fail (key = ksLookupByName(ks, "user/tests/fstab/\\/media\\/ext4/dumpfreq",0), "rootfs device not found");
 	succeed_if (strcmp( "0", keyValue(key)) == 0, "dumpfreq not correct");
 
 	ksDel(ks);
@@ -55,57 +59,43 @@ void test_readfstab()
 	PLUGIN_CLOSE();
 }
 
-#if 0
-
 void test_writefstab(const char * file)
 {
-	KDB *kdb = kdbOpen();
-	KeySet *ks;
-	KeySet *conf;
-	Key* mnt;
+	KeySet *conf = 0;
+	PLUGIN_OPEN("fstab");
 
-	FILE *fstab_writer = fopen (file, "w");
-	fprintf (fstab_writer, "\n"); /* make empty */
-	fclose (fstab_writer);
+	printf ("Writing fstab using file: %s\n", file);
 
-	printf("Test mount writefstab\n");
-
-	succeed_if (kdbMount (kdb, mnt=keyNew("user/tests/filesystems",KEY_VALUE, "fstab", KEY_END),
-		conf=ksNew (2,keyNew("system/path", KEY_VALUE, file, KEY_END), KS_END)) == 0,
-		"could not mount fstab");
-	keyDel(mnt);
-	ksDel (conf);
-
-	ks = ksNew( 22 ,
+	KeySet *ks = ksNew( 22 ,
 			keyNew ("user/tests/filesystems"
 				, KEY_VALUE, "filesystems"
 				, KEY_COMMENT, ""
 			, KEY_END),
-			keyNew ("user/tests/filesystems/rootfs"
-				, KEY_VALUE, "non-rootfs"
+			keyNew ("user/tests/filesystems/\\/"
+				, KEY_VALUE, "the root fs"
 				, KEY_COMMENT, "pseudo name"
 			, KEY_END),
-			keyNew ("user/tests/filesystems/rootfs/device"
+			keyNew ("user/tests/filesystems/\\//device"
 				, KEY_VALUE, "/dev/sda6"
 				, KEY_COMMENT, "Device or Label"
 			, KEY_END),
-			keyNew ("user/tests/filesystems/rootfs/dumpfreq"
+			keyNew ("user/tests/filesystems/\\//dumpfreq"
 				, KEY_VALUE, "0"
 				, KEY_COMMENT, "Dump frequency in days"
 			, KEY_END),
-			keyNew ("user/tests/filesystems/rootfs/mpoint"
+			keyNew ("user/tests/filesystems/\\//mpoint"
 				, KEY_VALUE, "/"
 				, KEY_COMMENT, "Moint point"
 			, KEY_END),
-			keyNew ("user/tests/filesystems/rootfs/options"
+			keyNew ("user/tests/filesystems/\\//options"
 				, KEY_VALUE, "defaults,errors=remount-ro"
 				, KEY_COMMENT, "Fileuser/tests specific options. See mount(8)"
 			, KEY_END),
-			keyNew ("user/tests/filesystems/rootfs/passno"
+			keyNew ("user/tests/filesystems/\\//passno"
 				, KEY_VALUE, "1"
 				, KEY_COMMENT, "Pass number on parallel fsck"
 			, KEY_END),
-			keyNew ("user/tests/filesystems/rootfs/type"
+			keyNew ("user/tests/filesystems/\\//type"
 				, KEY_VALUE, "jfs"
 				, KEY_COMMENT, "Fileuser/tests type. See fs(5)"
 			, KEY_END),
@@ -138,13 +128,24 @@ void test_writefstab(const char * file)
 				, KEY_COMMENT, "Fileuser/tests type. See fs(5)"
 			, KEY_END),
 			KS_END);
-	succeed_if (kdbSet (kdb, ks, keyNew ("user/tests/filesystems",0) ,KDB_O_DEL) == 15, "could not set keys");
-	/*printf ("%d\n", kdbSet (kdb, ks, keyNew ("user/tests/filesystems",0) ,KDB_O_DEL));*/
-	ksDel (ks);
-	kdbClose (kdb);
-}
 
-#endif
+	Key *parentKey = keyNew ("user/tests/filesystems", KEY_VALUE,
+			elektraFilename(), KEY_END);
+	succeed_if(plugin->kdbSet (plugin, ks, parentKey) == 1,
+			"kdbSet was not successful");
+	succeed_if(output_error (parentKey), "error in kdbSet");
+	succeed_if(output_warnings (parentKey), "warnings in kdbSet");
+
+	succeed_if( compare_line_files (srcdir_file (file), keyString (parentKey)),
+		    "files do not match as expected");
+
+	elektraUnlink(keyString (parentKey));
+	keyDel(parentKey);
+
+	ksDel (ks);
+
+	PLUGIN_CLOSE ();
+}
 
 int main(int argc, char** argv)
 {
@@ -153,8 +154,8 @@ int main(int argc, char** argv)
 
 	init (argc, argv);
 
-	// test_writefstab();
-	test_readfstab();
+	test_readfstab("fstab/fstab");
+	test_writefstab("fstab/fstab-write");
 
 	printf("\ntestmod_fstab RESULTS: %d test(s) done. %d error(s).\n", nbTest, nbError);
 
