@@ -30,8 +30,6 @@ ksNew (30,
 			KEY_FUNC, elektraGlobMatch,
 			KEY_END),
 #include "readme_glob.c"
-		keyNew ("system/elektra/modules/glob/infos/ordering",
-			KEY_VALUE, "check", KEY_END),
 		keyNew ("system/elektra/modules/glob/infos/version",
 			KEY_VALUE, PLUGINVERSION, KEY_END),
 		KS_END);
