@@ -116,20 +116,7 @@ int elektraHexcodeGet(Plugin *handle, KeySet *returned, Key *parentKey)
 				KEY_FUNC, elektraHexcodeOpen, KEY_END),
 			keyNew ("system/elektra/modules/hexcode/exports/close",
 				KEY_FUNC, elektraHexcodeClose, KEY_END),
-			keyNew ("system/elektra/modules/hexcode/infos",
-				KEY_VALUE, "All information you want to know", KEY_END),
-			keyNew ("system/elektra/modules/hexcode/infos/author",
-				KEY_VALUE, "Markus Raab <elektra@markus-raab.org>", KEY_END),
-			keyNew ("system/elektra/modules/hexcode/infos/licence",
-				KEY_VALUE, "BSD", KEY_END),
-			keyNew ("system/elektra/modules/hexcode/infos/description",
-				KEY_VALUE, "Decoding/Encoding engine which escapes unwanted characters.", KEY_END),
-			keyNew ("system/elektra/modules/hexcode/infos/provides",
-				KEY_VALUE, "code", KEY_END),
-			keyNew ("system/elektra/modules/hexcode/infos/placements",
-				KEY_VALUE, "postgetstorage presetstorage", KEY_END),
-			keyNew ("system/elektra/modules/hexcode/infos/needs",
-				KEY_VALUE, "", KEY_END),
+#include "readme_hexcode.c"
 			keyNew ("system/elektra/modules/hexcode/infos/version",
 				KEY_VALUE, PLUGINVERSION, KEY_END),
 			KS_END);
