@@ -76,7 +76,7 @@ int ini_parse_file(FILE* file,const struct IniConfig* config, void* user)
     char* value;
     int lineno = 0;
     int error = 0;
-
+    unsigned short toMeta = config->keyToMeta;
 #if !INI_USE_STACK
     line = (char*)malloc(INI_MAX_LINE);
     if (!line) {
@@ -108,7 +108,7 @@ int ini_parse_file(FILE* file,const struct IniConfig* config, void* user)
         else if (config->supportMultiline && *prev_name && *start && start > line) {
             /* Non-black line with leading whitespace, treat as continuation
                of previous name's value (as per Python ConfigParser). */
-            if (!config->keyHandler(user, section, prev_name, start, 1) && !error)
+            if (!config->keyHandler(user, section, prev_name, start, toMeta, 1) && !error)
                 error = lineno;
         }
         else if (*start == '[') {
@@ -143,12 +143,15 @@ int ini_parse_file(FILE* file,const struct IniConfig* config, void* user)
 
                 /* Valid name[=:]value pair found, call handler */
                 strncpy0(prev_name, name, sizeof(prev_name));
-                if (!config->keyHandler(user, section, name, value, 0) && !error)
+                if (!config->keyHandler(user, section, name, value, toMeta, 0) && !error)
                     error = lineno;
             }
             else if (!error) {
-                /* No '=' or ':' found on name[=:]value line */
-                error = lineno;
+				end = find_char_or_comment(start, '\0');
+				name = rstrip(start);
+				strncpy0(prev_name, name, sizeof(prev_name));
+				if(!config->keyHandler(user, section, name, NULL, toMeta, 0) && ! error)
+					error = lineno;
             }
         }
 
