@@ -71,7 +71,7 @@ static void test_plainIniWrite(char *fileName)
 					KEY_VALUE, "nosectionvalue",
 					KEY_END),
 			keyNew ("user/tests/ini-write/section1",
-					KEY_BINARY,
+					KEY_BINARY, 
 					KEY_END),
 			keyNew ("user/tests/ini-write/section1/key1",
 					KEY_VALUE, "value1",
@@ -103,7 +103,59 @@ static void test_plainIniWrite(char *fileName)
 	PLUGIN_CLOSE ();
 }
 
+static void test_plainIniEmptyWrite(char *fileName)
+{
+	Key *parentKey = keyNew ("user/tests/ini-write", KEY_VALUE,
+			elektraFilename(), KEY_END);
+	KeySet *conf = ksNew(0, KS_END);
+	PLUGIN_OPEN("ini");
 
+	KeySet *ks = ksNew (30,
+			keyNew ("user/tests/ini-write/nosectionkey",
+					KEY_VALUE, "nosectionvalue",
+					KEY_END),
+			keyNew ("user/tests/ini-write/section1",
+					KEY_BINARY,
+
+					KEY_END),
+			keyNew ("user/tests/ini-write/section1/key1",
+					KEY_VALUE, "value1",
+					KEY_END),
+			keyNew ("user/tests/ini-write/section1/key2",
+					KEY_VALUE, "value2",
+					KEY_END),
+			keyNew ("user/tests/ini-write/section2",
+					KEY_BINARY,
+
+					KEY_END),
+			keyNew ("user/tests/ini-write/section2/key3",
+					KEY_VALUE, "value3",
+					KEY_END),
+			keyNew ("user/tests/ini-write/section2/emptykey", KEY_META, "ini/empty", "", KEY_END),
+			KS_END);
+
+	succeed_if(plugin->kdbSet (plugin, ks, parentKey) >= 1,
+			"call to kdbSet was not successful");
+	succeed_if(output_error (parentKey), "error in kdbSet");
+	succeed_if(output_warnings (parentKey), "warnings in kdbSet");
+
+	succeed_if(
+			compare_line_files (srcdir_file (fileName), keyString (parentKey)),
+			"files do not match as expected");
+
+	KeySet *readKS = ksNew(0, KS_END);
+	succeed_if(plugin->kdbGet(plugin, readKS, parentKey) >= 0, "kdbGet failed");
+	const Key *meta;
+	Key *searchKey = keyNew ("user/tests/ini-write/section2/emptykey", KEY_META, "ini/empty", "", KEY_END);
+	Key *key = ksLookup(readKS, searchKey, KDB_O_NONE);
+	meta = keyGetMeta(key, "ini/empty");
+	succeed_if(meta != NULL, "reading empty key again failed");
+	ksDel(readKS);
+	ksDel (ks);
+	keyDel (parentKey);
+	keyDel (searchKey);
+	PLUGIN_CLOSE ();
+}
 static void test_commentIniRead(char *fileName)
 {
 	Key *parentKey = keyNew ("user/tests/ini-read", KEY_VALUE,
@@ -156,7 +208,8 @@ static void test_commentIniWrite(char *fileName)
 					KEY_COMMENT, "nosection comment1\nnosection comment2",
 					KEY_END),
 			keyNew ("user/tests/ini-write/section1",
-					KEY_BINARY,
+					KEY_BINARY, 
+
 					KEY_COMMENT, "section comment1\nsection comment2",
 					KEY_END),
 			keyNew ("user/tests/ini-write/section1/key1",
@@ -225,11 +278,13 @@ static void test_multilineIniWrite(char *fileName)
 	PLUGIN_OPEN("ini");
 
 	KeySet *ks = ksNew (30,
-			keyNew ("user/tests/ini-multiline-write/multilinesection", KEY_BINARY, KEY_END),
+			keyNew ("user/tests/ini-multiline-write/multilinesection", KEY_BINARY, 
+ KEY_END),
 			keyNew ("user/tests/ini-multiline-write/multilinesection/key1",
 					KEY_VALUE, "value1\nwith continuation\nlines",
 					KEY_END),
-			keyNew ("user/tests/ini-multiline-write/singlelinesection", KEY_BINARY, KEY_END),
+			keyNew ("user/tests/ini-multiline-write/singlelinesection", KEY_BINARY, 
+ KEY_END),
 			keyNew ("user/tests/ini-multiline-write/singlelinesection/key2",
 					KEY_VALUE, "",
 					KEY_END),
@@ -259,7 +314,8 @@ static void test_multilineIniInvalidConfigWrite()
 	PLUGIN_OPEN("ini");
 
 	KeySet *ks = ksNew (30,
-			keyNew ("user/tests/ini-multiline-write/multilinesection", KEY_BINARY, KEY_END),
+			keyNew ("user/tests/ini-multiline-write/multilinesection", KEY_BINARY, 
+ KEY_END),
 			keyNew ("user/tests/ini-multiline-write/multilinesection/key1",
 					KEY_VALUE, "value1\nwith continuation\nlines",
 					KEY_END),
@@ -293,7 +349,7 @@ static void test_sectionRead(char *fileName)
 	succeed_if(output_error (parentKey), "error in kdbGet");
 	succeed_if(output_warnings (parentKey), "warnings in kdbGet");
 
-	Key *key = ksLookupByName (ks, "user/tests/ini-section-read/akey\\/looking\\/like\\/sections", KDB_O_NONE);
+	Key *key = ksLookupByName (ks, "user/tests/ini-section-read/akey/looking/like/sections", KDB_O_NONE);
 	exit_if_fail(key, "section like key not found not found");
 	succeed_if (!strcmp ("value", keyString(key)), "section like key contained invalid data");
 
@@ -311,16 +367,16 @@ static void test_sectionRead(char *fileName)
 	exit_if_fail(key, "key1 not found not found");
 	succeed_if (!strcmp ("value1", keyString(key)), "key1 contained invalid data");
 
-	key = ksLookupByName (ks, "user/tests/ini-section-read/section1/key\\/with\\/subkey", KDB_O_NONE);
+	key = ksLookupByName (ks, "user/tests/ini-section-read/section1/key/with/subkey", KDB_O_NONE);
 	exit_if_fail(key, "key with subkey not found not found");
 	succeed_if (!strcmp ("value2", keyString(key)), "key with subkey contained invalid data");
 
-	key = ksLookupByName(ks, "user/tests/ini-section-read/section2\\/with\\/subkey", KDB_O_NONE);
+	key = ksLookupByName(ks, "user/tests/ini-section-read/section2/with/subkey", KDB_O_NONE);
 	exit_if_fail(key, "section2 key not found");
 	succeed_if (keyIsBinary(key), "section2 key is not a binary key");
 	succeed_if (!keyValue(key), "section2 contains non null data");
 
-	key = ksLookupByName (ks, "user/tests/ini-section-read/section2\\/with\\/subkey/key2", KDB_O_NONE);
+	key = ksLookupByName (ks, "user/tests/ini-section-read/section2/with/subkey/key2", KDB_O_NONE);
 	exit_if_fail(key, "key2 not found not found");
 	succeed_if (!strcmp ("value2", keyString(key)), "key2 contained invalid data");
 
@@ -338,17 +394,20 @@ static void test_sectionWrite(char *fileName)
 	PLUGIN_OPEN("ini");
 
 	KeySet *ks = ksNew (30,
-			keyNew ("user/tests/ini-section-write/akey\\/looking\\/like\\/sections", KEY_VALUE, "value", KEY_END),
-			keyNew ("user/tests/ini-section-write/emptysection", KEY_BINARY, KEY_END),
-			keyNew ("user/tests/ini-section-write/section1", KEY_BINARY, KEY_END),
+			keyNew ("user/tests/ini-section-write/akey/looking/like/sections", KEY_VALUE, "value", KEY_END),
+			keyNew ("user/tests/ini-section-write/emptysection", KEY_BINARY, 
+ KEY_END),
+			keyNew ("user/tests/ini-section-write/section1", KEY_BINARY, 
+ KEY_END),
 			keyNew ("user/tests/ini-section-write/section1/key1",
 					KEY_VALUE, "value1",
 					KEY_END),
-			keyNew ("user/tests/ini-section-write/section1/key\\/with\\/subkey",
+			keyNew ("user/tests/ini-section-write/section1/key/with/subkey",
 					KEY_VALUE, "value2",
 					KEY_END),
-			keyNew("user/tests/ini-section-write/section2\\/with\\/subkey", KEY_BINARY, KEY_END),
-			keyNew("user/tests/ini-section-write/section2\\/with\\/subkey/key2",
+			keyNew("user/tests/ini-section-write/section2/with/subkey", KEY_BINARY, 
+ KEY_END),
+			keyNew("user/tests/ini-section-write/section2/with/subkey/key2",
 					KEY_VALUE, "value2",
 					KEY_END),
 			KS_END);
@@ -378,15 +437,15 @@ static void test_autoSectionWrite(char *fileName)
 
 	// this time the sections directly below the parent key will be generated automatically
 	KeySet *ks = ksNew (30,
-			keyNew ("user/tests/ini-section-write/akey\\/looking\\/like\\/sections", KEY_VALUE, "value", KEY_END),
-			keyNew ("user/tests/ini-section-write/emptysection", KEY_BINARY, KEY_END),
+			keyNew ("user/tests/ini-section-write/akey/looking/like/sections", KEY_VALUE, "value", KEY_META, "ini/noautosection", "", KEY_END),
+			keyNew ("user/tests/ini-section-write/emptysection", KEY_BINARY,  KEY_END),
 			keyNew ("user/tests/ini-section-write/section1/key1",
 					KEY_VALUE, "value1",
 					KEY_END),
-			keyNew ("user/tests/ini-section-write/section1/key\\/with\\/subkey",
+			keyNew ("user/tests/ini-section-write/section1/key/with/subkey",
 					KEY_VALUE, "value2",
 					KEY_END),
-			keyNew("user/tests/ini-section-write/section2\\/with\\/subkey/key2",
+			keyNew("user/tests/ini-section-write/section2\\/with\\/subkey/key2", 
 					KEY_VALUE, "value2",
 					KEY_END),
 			KS_END);
@@ -404,7 +463,105 @@ static void test_autoSectionWrite(char *fileName)
 
 	PLUGIN_CLOSE ();
 }
+static void test_iniToMeta(char *fileName)
+{
+	Key *parentKey = keyNew ("user/tests/ini-write", KEY_VALUE,
+			srcdir_file(fileName), KEY_END);
+	KeySet *conf = ksNew(10, 
+		   keyNew("system/meta", KEY_VALUE, "1", KEY_END),
+	   	   KS_END);
+	PLUGIN_OPEN("ini");
 
+	KeySet *readKS = ksNew(0, KS_END);
+	succeed_if(plugin->kdbGet(plugin, readKS, parentKey) >= 0, "kdbGet failed");
+	const Key *meta;
+	Key *searchKey = keyNew ("user/tests/ini-write/section1", KEY_END);
+	Key *key = ksLookup(readKS, searchKey, KDB_O_NONE);
+	meta = keyGetMeta(key, "key1");
+	succeed_if(meta != NULL, "converting key to metakey failed");
+	succeed_if(strcmp(keyString(meta), "value1") == 0, "wrong value in metakey");
+	ksDel(readKS);
+	keyDel (parentKey);
+	keyDel (searchKey);
+	PLUGIN_CLOSE ();
+}
+static void test_plainIniPreserveOrder(char *fileName)
+{
+	Key *parentKey = keyNew ("user/tests/ini-write", KEY_VALUE,
+			elektraFilename() , KEY_END);
+	KeySet *conf = ksNew(1,
+		   	keyNew("system/preserveorder", KEY_VALUE, "1", KEY_END)
+			, KS_END);
+	KeySet *ks = ksNew (30,
+		keyNew ("user/tests/ini-write/nosectionkey", KEY_META, "order", "0", 
+				KEY_VALUE, "nosectionvalue",
+				KEY_END),
+		keyNew ("user/tests/ini-write/section1", KEY_META, "order", "1", 
+				KEY_BINARY, 
+
+				KEY_END),
+		keyNew ("user/tests/ini-write/section1/key1", KEY_META, "order", "3", 
+				KEY_VALUE, "value1",
+				KEY_END),
+		keyNew ("user/tests/ini-write/section1/key2", KEY_META, "order", "2", 
+				KEY_VALUE, "value2",
+				KEY_END),
+		keyNew ("user/tests/ini-write/section2", KEY_META, "order", "4", 
+				KEY_BINARY, 
+
+				KEY_END),
+		keyNew ("user/tests/ini-write/section2/key3", KEY_META, "order", "6", 
+				KEY_VALUE, "value3",
+				KEY_END),
+		keyNew ("user/tests/ini-write/section2/zemptykey", KEY_META, "order", "5" , KEY_END),
+		KS_END);
+
+	PLUGIN_OPEN("ini");
+	succeed_if(plugin->kdbSet (plugin, ks, parentKey) >= 1,
+			"call to kdbSet was not successful");
+	succeed_if(output_error (parentKey), "error in kdbSet");
+	succeed_if(output_warnings (parentKey), "warnings in kdbSet");
+
+	succeed_if(
+			compare_line_files (srcdir_file (fileName), keyString (parentKey)),
+			"files do not match as expected");
+
+	ksDel (ks);
+	keyDel(parentKey);
+	PLUGIN_CLOSE ();
+}
+
+static void test_emptySectionBug(char *fileName)
+{
+	Key *parentKey = keyNew ("user/tests/ini-write", KEY_VALUE,
+			elektraFilename(), KEY_END);
+	KeySet *conf = ksNew(0, KS_END);
+	KeySet *ks = ksNew (30,
+		keyNew ("user/tests/ini-write/MyApp/mykey",  
+				KEY_VALUE, "new_value",
+				KEY_END),
+		keyNew ("user/tests/ini-write/binarytest",
+				KEY_BINARY,
+				KEY_END),
+		keyNew ("user/tests/ini-write/debienna/test",
+				KEY_VALUE, "value",
+				KEY_END), 
+		KS_END);
+
+	PLUGIN_OPEN("ini");
+	succeed_if(plugin->kdbSet (plugin, ks, parentKey) >= 1,
+			"call to kdbSet was not successful");
+	succeed_if(output_error (parentKey), "error in kdbSet");
+	succeed_if(output_warnings (parentKey), "warnings in kdbSet");
+
+	succeed_if(
+			compare_line_files (srcdir_file (fileName), keyString (parentKey)),
+			"files do not match as expected");
+
+	ksDel (ks);
+	keyDel(parentKey);
+	PLUGIN_CLOSE ();
+}
 int main(int argc, char** argv)
 {
 	printf ("INI       TESTS\n");
@@ -414,6 +571,9 @@ int main(int argc, char** argv)
 
 	test_plainIniRead ("ini/plainini");
 	test_plainIniWrite ("ini/plainini");
+	test_iniToMeta ("ini/plainini");
+	test_plainIniRead ("ini/emptyval");
+	test_plainIniEmptyWrite ("ini/emptyval");
 	test_commentIniRead ("ini/commentini");
 	test_commentIniWrite ("ini/commentini");
 	test_multilineIniRead ("ini/multilineini");
@@ -422,6 +582,8 @@ int main(int argc, char** argv)
 	test_sectionRead("ini/sectionini");
 	test_sectionWrite("ini/sectionini");
 	test_autoSectionWrite("ini/sectionini");
+	test_plainIniPreserveOrder("ini/plaininireverse");
+	test_emptySectionBug("ini/emptySectionBugTest");
 
 	printf ("\ntest_ini RESULTS: %d test(s) done. %d error(s).\n", nbTest,
 			nbError);
