@@ -33,20 +33,7 @@ int elektraJournaldGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *par
 		keyNew ("system/elektra/modules/journald/exports/error",
 			KEY_FUNC, elektraJournaldError,
 			KEY_END),
-		keyNew ("system/elektra/modules/journald/infos",
-			KEY_VALUE, "All information you want to know", KEY_END),
-		keyNew ("system/elektra/modules/journald/infos/author",
-			KEY_VALUE, "Felix Berlakovich <elektra@berlakovich.net>", KEY_END),
-		keyNew ("system/elektra/modules/journald/infos/licence",
-			KEY_VALUE, "BSD", KEY_END),
-		keyNew ("system/elektra/modules/journald/infos/description",
-			KEY_VALUE, "Logs set and error calls to journald", KEY_END),
-		keyNew ("system/elektra/modules/journald/infos/provides",
-			KEY_VALUE, "logging", KEY_END),
-		keyNew ("system/elektra/modules/journald/infos/placements",
-			KEY_VALUE, "postcommit postrollback", KEY_END),
-		keyNew ("system/elektra/modules/journald/infos/needs",
-			KEY_VALUE, "", KEY_END),
+#include "readme_journald.c"
 		keyNew ("system/elektra/modules/journald/infos/version",
 			KEY_VALUE, PLUGINVERSION, KEY_END),
 		KS_END));
