@@ -74,20 +74,7 @@ int elektraNetworkGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *pare
 		keyNew ("system/elektra/modules/network/exports/elektraNetworkAddrInfo",
 			KEY_FUNC, elektraNetworkAddrInfo,
 			KEY_END),
-		keyNew ("system/elektra/modules/network/infos",
-			KEY_VALUE, "All information you want to know", KEY_END),
-		keyNew ("system/elektra/modules/network/infos/author",
-			KEY_VALUE, "Markus Raab <elektra@markus-raab.org>", KEY_END),
-		keyNew ("system/elektra/modules/network/infos/licence",
-			KEY_VALUE, "BSD", KEY_END),
-		keyNew ("system/elektra/modules/network/infos/description",
-			KEY_VALUE, "Checks keys if they contain a valid ip address", KEY_END),
-		keyNew ("system/elektra/modules/network/infos/provides",
-			KEY_VALUE, "check", KEY_END),
-		keyNew ("system/elektra/modules/network/infos/placements",
-			KEY_VALUE, "presetstorage", KEY_END),
-		keyNew ("system/elektra/modules/network/infos/needs",
-			KEY_VALUE, "", KEY_END),
+#include "readme_network.c"
 		keyNew ("system/elektra/modules/network/infos/version",
 			KEY_VALUE, PLUGINVERSION, KEY_END),
 		KS_END));
