@@ -29,7 +29,10 @@
 # include "kdbconfig.h"
 #endif
 
+#include <kdberrors.h>
+
 #include <string.h>
+#include <errno.h>
 
 int elektraNiGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *parentKey)
 {
@@ -55,15 +58,28 @@ int elektraNiGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *parentKey
 	}
 
 	Ni_node root = Ni_New();
+	int errnosave = errno;
 	int error = Ni_ReadFile(root, keyString(parentKey), 0);
-	if (error == 0) return 0;
+	if (error == 0)
+	{
+		Ni_Free(root);
+		ELEKTRA_SET_ERROR_GET(parentKey);
+		errno = errnosave;
+		return -1;
+	}
 
 	Ni_node current = NULL;
 	while ((current = Ni_GetNextChild(root, current)) != NULL)
 	{
-		Key *k = keyNew(0);
-		keySetName (k, Ni_GetName(current, NULL));
+		Key *k = keyNew(keyName(parentKey), KEY_END);
+		keyAddName (k, Ni_GetName(current, NULL));
 		keySetString (k, Ni_GetValue (current, NULL));
+		Ni_node mcur = NULL;
+		while ((mcur = Ni_GetNextChild(current, mcur)) != NULL)
+		{
+			keySetMeta (k, Ni_GetName(mcur, NULL), Ni_GetValue (mcur, NULL));
+			// printf("get meta %s %s from %s\n", Ni_GetName(mcur, NULL), Ni_GetValue (mcur, NULL), keyName(k));
+		}
 		ksAppendKey (returned, k);
 	}
 
@@ -72,6 +88,20 @@ int elektraNiGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *parentKey
 	return 1; /* success */
 }
 
+static void keyMetaToNi(Ni_node add, Key *cur)
+{
+	Ni_SetValue (add, keyString(cur), keyGetValueSize(cur)-1);
+
+	const Key *m;
+	keyRewindMeta(cur);
+	while ((m = keyNextMeta(cur)) != 0)
+	{
+		// printf("set meta %s %s from %s\n", keyName(m), keyString(m), keyName(cur));
+		Ni_node madd = Ni_GetChild(add, keyName(m), keyGetNameSize(m)-1, 1, 0);
+		Ni_SetValue (madd, keyString(m), keyGetValueSize(m)-1);
+	}
+}
+
 int elektraNiSet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *parentKey)
 {
 	/* set all keys */
@@ -80,17 +110,35 @@ int elektraNiSet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *parentKey
 
 	Key *cur;
 	ksRewind (returned);
-	while ((cur = ksNext(returned)) != 0)
+
+	if (keyCmp(ksHead(returned), parentKey) == 0)
 	{
-		Ni_node add = Ni_GetChild(root, keyName(cur), keyGetNameSize(cur)-1, 1, 0);
-		Ni_SetValue (add, keyString(cur), keyGetValueSize(cur)-1);
+		// printf ("found parentkey");
+		Ni_node add = Ni_GetChild(root, NULL, 0, 1, 0);
+		keyMetaToNi(add, ksHead(returned));
+		ksNext(returned); // do not process parent in loop again
 	}
 
-	int error = Ni_WriteFile (root,  keyString(parentKey), 0);
+	const size_t parentSize = keyGetNameSize(parentKey);
+	while ((cur = ksNext(returned)) != 0)
+	{
+		const size_t curSize = keyGetNameSize(cur);
+		Ni_node add = Ni_GetChild(root, keyName(cur)+parentSize, curSize-parentSize-1, 1, 0);
+		keyMetaToNi(add, cur);
+	}
 
+	int errnosave = errno;
+	int error = Ni_WriteFile (root,  keyString(parentKey), 0);
 	Ni_Free(root);
 
-	return error != 0; /* success */
+	if (error == 0)
+	{
+		ELEKTRA_SET_ERROR_SET(parentKey);
+		errno = errnosave;
+		return -1;
+	}
+
+	return 1; /* success */
 }
 
 Plugin *ELEKTRA_PLUGIN_EXPORT(ni)
