@@ -44,20 +44,7 @@ int elektraNullGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *parentK
 				KEY_FUNC, elektraNullGet, KEY_END),
 			keyNew ("system/elektra/modules/null/exports/set",
 				KEY_FUNC, elektraNullSet, KEY_END),
-			keyNew ("system/elektra/modules/null/infos",
-				KEY_VALUE, "All information you want to know", KEY_END),
-			keyNew ("system/elektra/modules/null/infos/author",
-				KEY_VALUE, "Markus Raab <elektra@markus-raab.org>", KEY_END),
-			keyNew ("system/elektra/modules/null/infos/licence",
-				KEY_VALUE, "BSD", KEY_END),
-			keyNew ("system/elektra/modules/null/infos/description",
-				KEY_VALUE, "Avoids null and empty values", KEY_END),
-			keyNew ("system/elektra/modules/null/infos/provides",
-				KEY_VALUE, "", KEY_END),
-			keyNew ("system/elektra/modules/null/infos/placements",
-				KEY_VALUE, "postgetstorage presetstorage", KEY_END),
-			keyNew ("system/elektra/modules/null/infos/needs",
-				KEY_VALUE, "", KEY_END),
+#include "readme_null.c"
 			keyNew ("system/elektra/modules/null/infos/version",
 				KEY_VALUE, PLUGINVERSION, KEY_END),
 			KS_END);
