@@ -43,20 +43,7 @@ int elektraPathGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *parentK
 		keyNew ("system/elektra/modules/path/exports/set",
 			KEY_FUNC, elektraPathSet,
 			KEY_END),
-		keyNew ("system/elektra/modules/path/infos",
-			KEY_VALUE, "All information you want to know", KEY_END),
-		keyNew ("system/elektra/modules/path/infos/author",
-			KEY_VALUE, "Markus Raab <elektra@markus-raab.org>", KEY_END),
-		keyNew ("system/elektra/modules/path/infos/licence",
-			KEY_VALUE, "BSD", KEY_END),
-		keyNew ("system/elektra/modules/path/infos/description",
-			KEY_VALUE, "Checks if keys enriched with appropriate metadata contain valid paths as values", KEY_END),
-		keyNew ("system/elektra/modules/path/infos/provides",
-			KEY_VALUE, "check", KEY_END),
-		keyNew ("system/elektra/modules/path/infos/placements",
-			KEY_VALUE, "presetstorage", KEY_END),
-		keyNew ("system/elektra/modules/path/infos/needs",
-			KEY_VALUE, "", KEY_END),
+#include "readme_path.c"
 		keyNew ("system/elektra/modules/path/infos/version",
 			KEY_VALUE, PLUGINVERSION, KEY_END),
 		KS_END));
