@@ -3,7 +3,6 @@
  */
 
 #include <stdlib.h>
-#include <Python.h>
 
 #ifdef HAVE_KDBCONFIG_H
 #include "kdbconfig.h"
@@ -11,26 +10,33 @@
 
 #include <tests_plugin.h>
 
-static int Python_AppendToSysPath(const char *path)
-{
-	if (path == NULL)
-		return 0;
-
-	PyGILState_STATE gstate = PyGILState_Ensure();
-	PyObject *sysPath = PySys_GetObject((char *)"path");
-	PyObject *pyPath  = PyUnicode_FromString(path);
-	PyList_Append(sysPath, pyPath);
-	Py_DECREF(pyPath);
-	PyGILState_Release(gstate);
-	return 1;
-}
-
-static void init_python()
+static void init_env()
 {
 	setenv("PYTHONDONTWRITEBYTECODE", "1", 1);
-	if (!Py_IsInitialized())
-		Py_Initialize();
-	Python_AppendToSysPath(".");
+	setenv("PYTHONPATH", ".", 1);
+}
+
+char filebuf[KDB_MAX_PATH_LENGTH];
+static char *srcdir_rewrite = NULL;
+static char *python_file(const char *filename)
+{
+	if (!srcdir_rewrite)
+	{
+		/* no rewrite. just append our plugin name */
+		strcpy(filebuf, PYTHON_PLUGIN_NAME);
+		strcat(strcat(filebuf, "/"), filename);
+		return srcdir_file(filebuf);
+	}
+
+	/* wipe old value */
+	*srcdir_rewrite = '\0';
+
+	/* append plugin name and delete last character */
+	strcat(strcat(filebuf, "/"), PYTHON_PLUGIN_NAME);
+	*(filebuf + strlen(filebuf) - 1) = '\0';
+
+	strcat(strcat(filebuf, "/"), filename);
+	return filebuf;
 }
 
 // test simple variable passing
@@ -38,10 +44,9 @@ static void test_variable_passing()
 {
 	printf("Testing simple variable passing...\n");
 
-	init_python();
-
 	KeySet *conf = ksNew(1,
-		keyNew("user/script", KEY_VALUE, srcdir_file(PYTHON_PLUGIN_NAME "/python_plugin.py"), KEY_END),
+		keyNew("user/script", KEY_VALUE, python_file("python_plugin.py"), KEY_END),
+		keyNew("user/shutdown", KEY_VALUE, "1", KEY_END),
 		keyNew("user/print", KEY_END),
 		KS_END);
 	PLUGIN_OPEN(PYTHON_PLUGIN_NAME);
@@ -50,7 +55,7 @@ static void test_variable_passing()
 	KeySet *ks = ksNew(0, KS_END);
 	succeed_if(plugin->kdbGet(plugin, ks, parentKey) >= 1, "call to kdbGet was not successful");
 	succeed_if(ksGetSize(ks) == 1, "keyset size is still 0");
-	succeed_if(!strcmp(keyName(ksHead(ks)), "user/from_python"), "key in keyset has wrong name");
+	succeed_if(ksGetSize(ks) == 1 && !strcmp(keyName(ksHead(ks)), "user/from_python"), "key in keyset has wrong name");
 
 	ksDel(ks);
 	keyDel(parentKey);
@@ -63,18 +68,18 @@ static void test_two_scripts()
 {
 	printf("Testing loading of two active python plugins...\n");
 
-	init_python();
-
 	KeySet *modules = ksNew(0, KS_END);
 	elektraModulesInit(modules, 0);
 
 	KeySet *conf = ksNew(2,
-		keyNew("user/script", KEY_VALUE, srcdir_file(PYTHON_PLUGIN_NAME "/python_plugin.py"), KEY_END),
+		keyNew("user/script", KEY_VALUE, python_file("python_plugin.py"), KEY_END),
+		keyNew("user/shutdown", KEY_VALUE, "1", KEY_END),
 		keyNew("user/print", KEY_END),
 		KS_END);
 
 	KeySet *conf2 = ksNew(2,
-		keyNew("user/script", KEY_VALUE, srcdir_file(PYTHON_PLUGIN_NAME "/python_plugin2.py"), KEY_END),
+		keyNew("user/script", KEY_VALUE, python_file("python_plugin2.py"), KEY_END),
+		keyNew("user/shutdown", KEY_VALUE, "1", KEY_END),
 		keyNew("user/print", KEY_END),
 		KS_END);
 
@@ -103,10 +108,9 @@ static void test_fail()
 {
 	printf("Testing return values from python functions...\n");
 
-	init_python();
-
 	KeySet *conf = ksNew(2,
-		keyNew("user/script", KEY_VALUE, srcdir_file(PYTHON_PLUGIN_NAME "/python_plugin_fail.py"), KEY_END),
+		keyNew("user/script", KEY_VALUE, python_file("python_plugin_fail.py"), KEY_END),
+		keyNew("user/shutdown", KEY_VALUE, "1", KEY_END),
 		keyNew("user/print", KEY_END),
 		KS_END);
 	PLUGIN_OPEN(PYTHON_PLUGIN_NAME);
@@ -129,20 +133,19 @@ static void test_wrong()
 {
 	printf("Testing python script with wrong class name...\n");
 
-	init_python();
-
 	KeySet *modules = ksNew(0, KS_END);
 	elektraModulesInit(modules, 0);
 
 	KeySet *conf = ksNew(2,
-		keyNew("user/script", KEY_VALUE, srcdir_file(PYTHON_PLUGIN_NAME "/python_plugin_wrong.py"), KEY_END),
+		keyNew("user/script", KEY_VALUE, python_file("python_plugin_wrong.py"), KEY_END),
+		keyNew("user/shutdown", KEY_VALUE, "1", KEY_END),
 		keyNew("user/print", KEY_END),
 		KS_END);
 
 	Key *errorKey = keyNew("", KEY_END);
 	Plugin *plugin = elektraPluginOpen(PYTHON_PLUGIN_NAME, modules, conf, errorKey);
 	succeed_if(!output_warnings(errorKey), "we expect some warnings");
-	succeed_if(!output_error(errorKey),    "we exepect some errors");
+	succeed_if(!output_error(errorKey),    "we expect some errors");
 	succeed_if(plugin == NULL, "python plugin shouldn't be loadable");
 	keyDel(errorKey);
 
@@ -156,6 +159,19 @@ int main(int argc, char** argv)
 	printf("==================\n\n");
 
 	init(argc, argv);
+	if (argc > 1) {
+		strncpy(filebuf, argv[1], sizeof(filebuf));
+		/* our files are in pythons plugin directory
+		 * -> rewrite srcdir from xxx/python2 to xxx/python
+		 */
+		if (strlen(filebuf) > strlen("python2") && !strcmp(filebuf + strlen(filebuf)
+					- strlen("python2"), "python2"))
+		{
+			srcdir_rewrite = filebuf + strlen(filebuf) - 1;
+			*srcdir_rewrite = '\0';
+		}
+	}
+	init_env();
 
 	test_variable_passing();
 	test_two_scripts();
