@@ -62,9 +62,6 @@ static void checkSimpleTestKeys(KeySet* ks)
 	succeed_if(key, "key1 was not correctly renamed");
 	key = ksLookupByName (ks, "user/tests/rename/key2", KDB_O_NONE);
 	succeed_if(key, "key2 was not correctly renamed");
-	/* the third key was not renamed because it would replace the parent key */
-	key = ksLookupByName (ks, "user/tests/rename/will/be/stripped", KDB_O_NONE);
-	succeed_if(key, "key3 was renamed but would replace the parent key");
 	/* the fourth key was not renamed because the prefix did not match */
 	key = ksLookupByName (ks, "user/tests/rename/will/not/be/stripped/key4", KDB_O_NONE);
 	succeed_if(key, "key4 was renamed although its prefix did not match");
@@ -99,8 +96,13 @@ static void test_simpleCutOnGet () {
 
 	checkSimpleTestKeys (ks);
 
-	keyDel (parentKey);
 	ksDel(ks);
+
+	/*
+	 * this has to be done because the parentKey is not
+	 * part of ks anymore due to renaming
+	 */
+	keyDel(parentKey);
 	PLUGIN_CLOSE ();
 }
 
@@ -147,16 +149,24 @@ static void test_simpleCutRestoreOnSet () {
 	succeed_if(output_error (parentKey), "error in kdbSet");
 	succeed_if(output_warnings (parentKey), "warnings in kdbSet");
 
-
 	/* test that the keys have been correctly restored */
 	KeySet *expected = createSimpleTestKeys();
-	ksAppendKey(expected, parentKeyCopy);
+
+	/* the parent key is restored from user/tests/rename/will/be/stripped
+	 * and therefore will have its key value
+	 */
+	keySetString (parentKeyCopy, "value3");
+	ksAppendKey (expected, parentKeyCopy);
 
 	compareKeySets (ks, expected);
-	keyDel (parentKey);
-	keyDel (parentKeyCopy);
 	ksDel(expected);
 	ksDel(ks);
+
+	/*
+	 * this has to be done because the parentKey is not
+	 * part of ks anymore due to renaming
+	 */
+	keyDel(parentKey);
 	PLUGIN_CLOSE ();
 }
 
@@ -226,14 +236,8 @@ static void test_keyCutNamePart()
 	Key *result = elektraKeyCutNamePart(parentKey, parentKey, "wont/cut/this");
 	succeed_if (!result, "parentKey was modified although it should have been ignored");
 
-	/* don't allow to produce the parentKey with cutting */
-	Key *testKey = keyNew ("user/tests/rename/wont/cut/this", KEY_END);
-	result = elektraKeyCutNamePart(testKey, parentKey, "wont/cut/this");
-	succeed_if (!result, "key was cut although it is identical with the parentKey afterwards");
-	keyDel(testKey);
-
 	/* cutting works correctly without trailing slash */
-	testKey = keyNew ("user/tests/rename/will/cut/this/key1", KEY_END);
+	Key *testKey = keyNew ("user/tests/rename/will/cut/this/key1", KEY_END);
 	result = elektraKeyCutNamePart(testKey, parentKey, "will/cut/this");
 	succeed_if (result, "key1 was not cut")
 	succeed_if (!strcmp(keyName(result), "user/tests/rename/key1"), "cutting key1 did not yield the expected result");
