@@ -10,6 +10,8 @@ ksNew (50,
 		KEY_VALUE, KDB_DB_USER, KEY_END),
 	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/constants/KDB_DB_SPEC",
 		KEY_VALUE, KDB_DB_SPEC, KEY_END),
+	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/constants/KDB_DB_DIR",
+		KEY_VALUE, KDB_DB_DIR, KEY_END),
 	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/constants/ELEKTRA_VARIANT_SYSTEM",
 		KEY_VALUE, ELEKTRA_VARIANT_SYSTEM, KEY_END),
 	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/constants/ELEKTRA_VARIANT_USER",
