@@ -46,6 +46,7 @@ struct _resolverHandle
 	struct timespec mtime; ///< Previous timestamp of the file
 	mode_t filemode;  ///< The mode to set (from previous file)
 	mode_t dirmode;  ///< The mode to set for new directories
+	int removalNeeded; ///< Error on freshly created files need removal
 
 	char *dirname; ///< directory where real+temp file is
 	char *filename;///< the full path to the configuration file
@@ -60,6 +61,8 @@ typedef struct _resolverHandles resolverHandles;
 
 struct _resolverHandles
 {
+	resolverHandle spec;
+	resolverHandle dir;
 	resolverHandle user;
 	resolverHandle system;
 };
