@@ -138,20 +138,7 @@ int elektraTimeofdayGet(Plugin *handle, KeySet *returned, Key *parentKey)
 				KEY_FUNC, elektraTimeofdaySet, KEY_END),
 			keyNew ("system/elektra/modules/timeofday/exports/error",
 				KEY_FUNC, elektraTimeofdayError, KEY_END),
-			keyNew ("system/elektra/modules/timeofday/infos",
-				KEY_VALUE, "All information you want to know", KEY_END),
-			keyNew ("system/elektra/modules/timeofday/infos/author",
-				KEY_VALUE, "Markus Raab <elektra@markus-raab.org>", KEY_END),
-			keyNew ("system/elektra/modules/timeofday/infos/licence",
-				KEY_VALUE, "BSD", KEY_END),
-			keyNew ("system/elektra/modules/timeofday/infos/description",
-				KEY_VALUE, "Prints timestamps when a method is called", KEY_END),
-			keyNew ("system/elektra/modules/timeofday/infos/provides",
-				KEY_VALUE, "logging", KEY_END),
-			keyNew ("system/elektra/modules/timeofday/infos/placements",
-				KEY_VALUE, "pregetstorage postgetstorage presetstorage precommit postcommit prerollback postrollback", KEY_END),
-			keyNew ("system/elektra/modules/timeofday/infos/needs",
-				KEY_VALUE, "", KEY_END),
+#include "readme_timeofday.c"
 			keyNew ("system/elektra/modules/timeofday/infos/version",
 				KEY_VALUE, PLUGINVERSION, KEY_END),
 			KS_END);
