@@ -45,20 +45,7 @@ int elektraValidationGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned, Key *p
 		keyNew ("system/elektra/modules/validation/exports/ksLookupRE",
 			KEY_FUNC, ksLookupRE,
 			KEY_END),
-		keyNew ("system/elektra/modules/validation/infos",
-			KEY_VALUE, "All information you want to know", KEY_END),
-		keyNew ("system/elektra/modules/validation/infos/author",
-			KEY_VALUE, "Markus Raab <elektra@markus-raab.org>", KEY_END),
-		keyNew ("system/elektra/modules/validation/infos/licence",
-			KEY_VALUE, "BSD", KEY_END),
-		keyNew ("system/elektra/modules/validation/infos/description",
-			KEY_VALUE, "Validates key values using regular expressions", KEY_END),
-		keyNew ("system/elektra/modules/validation/infos/provides",
-			KEY_VALUE, "check", KEY_END),
-		keyNew ("system/elektra/modules/validation/infos/placements",
-			KEY_VALUE, "presetstorage", KEY_END),
-		keyNew ("system/elektra/modules/validation/infos/needs",
-			KEY_VALUE, "", KEY_END),
+#include "readme_validation.c"
 		keyNew ("system/elektra/modules/validation/infos/version",
 			KEY_VALUE, PLUGINVERSION, KEY_END),
 		KS_END));
