@@ -1,6 +1,7 @@
 #include "yajl.h"
 
 #include <stdio.h>
+#include <errno.h>
 #include <string.h>
 
 #include <kdberrors.h>
@@ -342,12 +343,16 @@ int elektraYajlGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned,
 	yajl_config(hand, yajl_allow_comments, 1);
 #endif
 
+	int errnosave = errno;
 	unsigned char fileData[65536];
 	int done = 0;
 	FILE * fileHandle = fopen(keyString(parentKey), "r");
 	if (!fileHandle)
 	{
-		return 0;
+		yajl_free(hand);
+		ELEKTRA_SET_ERROR_GET(parentKey);
+		errno = errnosave;
+		return -1;
 	}
 
 	while (!done)
@@ -362,6 +367,7 @@ int elektraYajlGet(Plugin *handle ELEKTRA_UNUSED, KeySet *returned,
 				ELEKTRA_SET_ERROR(76, parentKey,
 						keyString(parentKey));
 				fclose (fileHandle);
+				yajl_free(hand);
 				return -1;
 			}
 			done = 1;
