@@ -19,8 +19,9 @@ int printProblems(Key k, std::string action, int off)
 {
 	bool wo = k.getMeta<const kdb::Key>("warnings");
 	bool eo = k.getMeta<const kdb::Key>("error");
-	if (wo || eo) std::cerr << action << " of kdb yield following problems:" << std::endl;
+	if (wo || eo) std::cerr << "\n======\n" << action << " of kdb yield following problems:" << std::endl;
 	printWarnings(cerr, k);
+	printError(cerr, k);
 	return (wo + eo * 2) << off;
 }
 
@@ -28,27 +29,34 @@ int CheckCommand::execute(Cmdline const& cl)
 {
 	if (cl.arguments.size() == 0)
 	{
-		int ret = 0;
 		Key x;
-		KDB kdb (x);
-		ret += printProblems(x, "opening", 0);
+		try {
+			int ret = 0;
+			KDB kdb (x);
+			ret += printProblems(x, "opening", 0);
 
-		KeySet ks;
-		Key a("/", KEY_END);
-		kdb.get(ks, a);
-		ret += printProblems(a, "getting", 2);
+			KeySet ks;
+			Key a("/", KEY_END);
+			try {kdb.get(ks, a);} catch(...) {}
+			ret += printProblems(a, "getting", 2);
 
-		if (cl.force)
+			if (cl.force)
+			{
+				Key b("/", KEY_END);
+				try{kdb.set(ks, b);} catch(...) {}
+				ret += printProblems(b, "setting", 4);
+			}
+
+			Key y;
+			kdb.close(y);
+			ret += printProblems(y, "closing", 6);
+			return  ret;
+		}
+		catch(KDBException const & e)
 		{
-			Key b("/", KEY_END);
-			kdb.set(ks, b);
-			ret += printProblems(b, "setting", 4);
+			std::cerr << "a fatal problem occurred, could not open KDB. This should not happen" << std::endl;
+			return printProblems(x, "opening", 0);
 		}
-
-		Key y;
-		kdb.close(y);
-		ret += printProblems(y, "closing", 6);
-		return  ret;
 	}
 
 	if (cl.arguments.size() != 1)
