@@ -132,10 +132,6 @@ public:
 	virtual int execute (Cmdline const& cmdline) = 0;
 };
 
-#if __cplusplus > 199711L
 typedef std::unique_ptr<Command> CommandPtr;
-#else
-typedef std::auto_ptr<Command> CommandPtr;
-#endif
 
 #endif
