@@ -39,7 +39,7 @@ int ExportCommand::execute(Cmdline const& cl)
 		part.cut(systemElektra);
 	}
 
-	string format = "dump";
+	string format = cl.format;
 	if (argc > 1) format = cl.arguments[1];
 
 	string file = "/dev/stdout";
