@@ -16,7 +16,13 @@ int FileCommand::execute (Cmdline const& cl)
 	if (cl.arguments.size() != 1) throw invalid_argument ("Need one argument");
 
 	KeySet conf;
-	Key x(cl.arguments[0], KEY_END);
+	std::string name = cl.arguments[0];
+	if (name[0] == '/')
+	{
+		name = cl.ns + name;
+		std::cerr << "Using name " << name << std::endl;
+	}
+	Key x(name, KEY_END);
 	if (!x.isValid())
 	{
 		throw invalid_argument(cl.arguments[0] + " is not an valid keyname");
