@@ -6,6 +6,7 @@
 
 #include <command.hpp>
 #include <merging/threewaymerge.hpp>
+#include <merging/mergeconfiguration.hpp>
 
 using namespace std;
 using namespace kdb::tools::merging;
@@ -15,14 +16,14 @@ class MergeHelper
 public:
 	MergeHelper();
 	virtual ~MergeHelper();
-	vector<MergeConflictStrategy*> getAllStrategies();
-	string getStrategyList();
-	void parseStrategies(Cmdline const& cl, ThreeWayMerge& merger);
+	vector<MergeConfiguration *> getAllConfigurations();
+	string getConfigurationList();
+	void configureMerger(Cmdline const& cl, ThreeWayMerge& merger);
 	void reportResult(Cmdline const& cl, MergeResult& result, ostream& out, ostream& err);
 
 
 private:
-	map<string, MergeConflictStrategy*> strategyMap;
+	map<string, MergeConfiguration *> configurationMap;
 
 };
 
