@@ -13,11 +13,15 @@ MetaLsCommand::MetaLsCommand()
 
 int MetaLsCommand::execute (Cmdline const& cl)
 {
+
+	if(cl.arguments.size() != 1){
+		throw invalid_argument("1 argument required");
+	}
+
 	Key root (cl.arguments[0], KEY_END);
 	if (!root.isValid())
 	{
-		cerr << "Not a valid name supplied" << endl;
-		return 1;
+		throw invalid_argument(cl.arguments[0] + " is not a valid keyname");
 	}
 
 	kdb.get(ks, root);
