@@ -15,7 +15,7 @@ public:
 
 	virtual std::string getShortOptions()
 	{
-		return "";
+		return "v";
 	}
 
 	virtual std::string getSynopsis()
@@ -37,6 +37,9 @@ public:
 			"interface because it is error-prone to directly\n"
 			"edit metadata.\n"
 			"\n"
+			"When a key does not exist, it will automatically created\n"
+			"with an initial empty value\n"
+			"\n"
 			"There is some special handling for the metadata\n"
 			"atime, mtime and ctime. They will be converted to\n"
 			"time_t.\n";
