@@ -15,7 +15,7 @@ public:
 
 	virtual std::string getShortOptions()
 	{
-		return "";
+		return "v";
 	}
 
 	virtual std::string getSynopsis()
@@ -34,10 +34,6 @@ public:
 	}
 
 	virtual int execute (Cmdline const& cmdline);
-
-private:
-	int deleteByBackendName(kdb::KeySet& mountConf, std::string const & backendName);
-	int deleteByMountPath(kdb::KeySet& mountCOnf, std::string const & mountPath);
 };
 
 #endif
