@@ -104,15 +104,17 @@ void ConfigNode::setName(const QString& name)
 
 	if(index != -1)
 	{
-		m_path.replace(index, m_path.length() - index,"/" + name);
+		m_path.replace(index, m_path.length() - index, "/" + name);
 	}
 
 	if(!m_key)
 		m_key = Key(m_path.toStdString(), KEY_END);
-
+	else
+		m_key = m_key.dup();
 
 	try{
-		m_key.setBaseName(name.toStdString());
+		if(m_key.getBaseName().compare(name.toStdString()) != 0)
+			m_key.setBaseName(name.toStdString());
 	}
 	catch(KeyInvalidName const& ex){
 		emit showMessage(tr("Error"), tr("Could not set name because Keyname \"%1\" is invalid.").arg(name), ex.what());
@@ -126,9 +128,14 @@ void ConfigNode::setValue(const QVariant& value)
 {
 	if(!m_key)
 		m_key = Key(m_path.toStdString(), KEY_END);
+	else
+		m_key = m_key.dup();
 
-	m_key.setString(value.toString().toStdString());
-	m_value = value;
+	if(m_key.getString().compare(value.toString().toStdString()) != 0)
+	{
+		m_key.setString(value.toString().toStdString());
+		m_value = value;
+	}
 }
 
 
@@ -136,6 +143,8 @@ void ConfigNode::setMeta(const QString &name, const QVariant &value)
 {
 	if(!m_key)
 		m_key = Key(m_path.toStdString(), KEY_END);
+	else
+		m_key = m_key.dup();
 
 	m_key.setMeta(name.toStdString(), value.toString().toStdString());
 	m_name = name;
