@@ -5,12 +5,21 @@ DeleteKeyCommand::DeleteKeyCommand(const QString& type, TreeViewModel* model, in
 	, m_model(model)
 	, m_node(model->model().at(index))
 	, m_index(index)
+	, m_isRoot(false)
 {
 	setText(type);
+
+	if(!m_node->getPath().contains('/'))
+	{
+		m_isRoot = true;
+		m_root = ConfigNodePtr(new ConfigNode(m_node->getPath(), m_node->getPath(), 0, m_model));
+	}
 }
 
 void DeleteKeyCommand::undo()
 {
+	if(m_isRoot)
+		m_model->removeRow(m_index);
 	m_model->insertRow(m_index, m_node);
 	m_model->refreshArrayNumbers();
 	m_model->refresh();
@@ -19,5 +28,7 @@ void DeleteKeyCommand::undo()
 void DeleteKeyCommand::redo()
 {
 	m_model->removeRow(m_index);
+	if(m_isRoot)
+		m_model->insertRow(m_index, m_root, false);
 	m_model->refreshArrayNumbers();
 }
