@@ -54,6 +54,12 @@ public:
 	 */
 	explicit TreeViewModel(QObject* parentModel =  0);
 
+	/**
+	 * @brief Constructor for root node.
+	 * @param parentModel An optional parent.
+	 */
+	explicit TreeViewModel(kdb::KDB * kdb, QObject* parentModel =  0);
+
 	/**
 	 * @brief The mandatory copy constructor.
 	 * @param The TreeViewModel that is copied.
@@ -265,10 +271,16 @@ public:
 	 */
 	QStringList					getSplittedKeyname(const kdb::Key &key);
 
+	/**
+	 * @brief discardModel Allow the QML side to destroy this model, even if this model is owned by C++.
+	 */
+	Q_INVOKABLE void			discardModel();
+
 private:
 	QList<ConfigNodePtr> m_model;
 	kdb::Key m_root;
-	kdb::KDB m_kdb;
+	kdb::KDB * m_kdb; // only held by root node of TreeViewModel
+	kdb::KeySet m_base; // only held by root node of TreeViewModel
 	kdb::Key m_metaModelParent;
 	/**
 	 * @brief Returns a MergeConflictStrategy object based on the name of the MergeConflictStrategy.
