@@ -16,8 +16,12 @@
 #define PLUGIN_OPEN(NAME) \
 		KeySet *modules = ksNew(0, KS_END); \
 		elektraModulesInit(modules, 0); \
-		Plugin *plugin = elektraPluginOpen(NAME, modules, conf, 0); \
-		exit_if_fail (plugin != 0, "could not open " NAME " plugin"); \
+		Key *errorKey = keyNew("", KEY_END); \
+		Plugin *plugin = elektraPluginOpen(NAME, modules, conf, errorKey); \
+		succeed_if(output_warnings (errorKey), "warnings in kdbOpen for plugin " NAME); \
+		succeed_if(output_error (errorKey), "error in kdbOpen for plugin " NAME); \
+		keyDel(errorKey); \
+		exit_if_fail(plugin != 0, "could not open " NAME " plugin");
 
 #define PLUGIN_CLOSE() \
 		elektraPluginClose (plugin, 0); \
