@@ -245,8 +245,8 @@ static void test_simpletrie()
 
 	Key *mp;
 	succeed_if ((mp = backend->mountpoint) != 0, "no mountpoint found");
-	succeed_if (!strcmp(keyName(mp), "user/tests/backend/simple"), "wrong mountpoint for backend");
-	succeed_if (!strcmp(keyString(mp), "simple"), "wrong name for backend");
+	succeed_if_same_string (keyName(mp), "user/tests/backend/simple");
+	succeed_if_same_string (keyString(mp), "simple");
 
 	Plugin *plugin = backend->getplugins[1];
 
@@ -350,8 +350,8 @@ static void test_two()
 
 	Key *mp;
 	succeed_if ((mp = backend->mountpoint) != 0, "no mountpoint found");
-	succeed_if (!strcmp(keyName(mp), "user/tests/backend/simple"), "wrong mountpoint for backend");
-	succeed_if (!strcmp(keyString(mp), "simple"), "wrong name for backend");
+	succeed_if_same_string (keyName(mp), "user/tests/backend/simple");
+	succeed_if_same_string (keyString(mp), "simple");
 
 	Plugin *plugin = backend->getplugins[1];
 
@@ -369,8 +369,8 @@ static void test_two()
 	succeed_if (two != backend, "should be differnt backend");
 
 	succeed_if ((mp = two->mountpoint) != 0, "no mountpoint found");
-	succeed_if (!strcmp(keyName(mp), "user/tests/backend/two"), "wrong mountpoint for backend two");
-	succeed_if (!strcmp(keyString(mp), "two"), "wrong name for backend");
+	succeed_if_same_string (keyName(mp), "user/tests/backend/two");
+	succeed_if_same_string (keyString(mp), "two");
 
 	keyDel (key);
 	elektraModulesClose (modules, 0);
@@ -420,8 +420,8 @@ static void test_us()
 
 	Key *mp;
 	succeed_if ((mp = backend->mountpoint) != 0, "no mountpoint found");
-	succeed_if (!strcmp(keyName(mp), "user"), "wrong mountpoint for backend");
-	succeed_if (!strcmp(keyString(mp), "user"), "wrong name for backend");
+	succeed_if_same_string (keyName(mp), "user");
+	succeed_if_same_string (keyString(mp), "user");
 
 
 	keySetName(key, "system/anywhere/tests/backend/two");
@@ -429,8 +429,8 @@ static void test_us()
 	succeed_if (two != backend, "should be differnt backend");
 
 	succeed_if ((mp = two->mountpoint) != 0, "no mountpoint found");
-	succeed_if (!strcmp(keyName(mp), "system"), "wrong mountpoint for backend two");
-	succeed_if (!strcmp(keyString(mp), "system"), "wrong name for backend");
+	succeed_if_same_string (keyName(mp), "system");
+	succeed_if_same_string (keyString(mp), "system");
 
 	keyDel (key);
 	elektraModulesClose (modules, 0);
