@@ -25,7 +25,13 @@ then
 	succeed_if "cannot set meta data"
 fi
 
-TMPFILE=`mktemp`
+TMPFILE="$(mktempfile_elektra)"
+cleanup()
+{
+	rm -f "$TMPFILE"
+}
+
+
 ERROR_FILE=${FILE_SUFFIX}_error.ecf
 #subfolders not supported:
 #USER_ERROR_FOLDER=${USER_FOLDER}/subfolder
