@@ -7,19 +7,29 @@ echo
 if pkg-config elektra
 then
 	echo "Installed Elektra will be used"
+	echo "We are assuming it is configured similarly"
+	echo "The test will fail if installed version does not use"
+	echo "same KDB."
 else
 	echo "Elektra or pkg-config not installed, will exit"
 	exit
 fi
 
+
 check_version
 
 EXTERNAL_FOLDER=@CMAKE_SOURCE_DIR@/examples/external
 
+set -x
+
 do_tests()
 {
 	SKEY=system/test/myapp/key
 	UKEY=user/test/myapp/key
+
+	$KDB rm "$SKEY"
+	$KDB rm "$UKEY"
+
 	VALUE="Hello World"
 	$KDB set "$SKEY"  "$VALUE"
 	succeed_if "could not set key $SKEY"
